#include <boost/math/special_functions/jacobi_theta.hpp>
#include "../boostmath/macros.hpp"

BINARY_BOOST_FUNCTION(jacobi_theta1, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta1tau, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta2, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta2tau, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta3, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta3tau, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta3m1, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta3m1tau, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta4, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta4tau, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta4m1, double, double);
BINARY_BOOST_FUNCTION(jacobi_theta4m1tau, double, double);
